@@ -10,23 +10,34 @@ import e3.log
 import e3.os.process
 
 if TYPE_CHECKING:
-    from typing import Optional
     from collections.abc import Callable
 
 logger = e3.log.getLogger("diff")
 
 
 class DiffError(e3.error.E3Error):
+    """Error returned when the patch command fails."""
+
+    pass
+
+
+class EmptyDiffError(DiffError):
+    """Error returned when the patch is empty.
+
+    These situation can occur when all the patched files are discarded.
+    """
+
     pass
 
 
 def diff(
     a: str | list[str],
     b: str | list[str],
-    ignore: Optional[str] = None,
+    ignore: str | None = None,
     item1name: str = "expected",
     item2name: str = "output",
     ignore_white_chars: bool = True,
+    context: int = 1,
 ) -> str:
     """Compute diff between two files or list of strings.
 
@@ -38,10 +49,12 @@ def diff(
     :param item2name: name to display for b in the diff
     :param ignore_white_chars: if True (default) then empty lines,
         trailing and leading white chars on each line are ignored
+    :param context: positive number of context lines to add to the diff
 
     :return: A diff string. If the string is equal to '' it means that there
         is no difference
     """
+    assert context >= 0
     contents: list[list[str]] = [[], []]
 
     # Read first item
@@ -82,14 +95,22 @@ def diff(
                 line for line in contents[k] if re.search(ignore, line) is None
             ]
 
-    return "".join(unified_diff(contents[0], contents[1], item1name, item2name, n=1))
+    return "".join(
+        unified_diff(
+            contents[0],
+            contents[1],
+            fromfile=item1name,
+            tofile=item2name,
+            n=context,
+        )
+    )
 
 
 def patch(
     patch_file: str,
     working_dir: str,
-    discarded_files: Optional[list[str] | Callable[[str], bool]] = None,
-    filtered_patch: Optional[str] = None,
+    discarded_files: list[str] | Callable[[str], bool] | None = None,
+    filtered_patch: str | None = None,
 ) -> None:
     """Apply a patch, ignoring changes in files matching discarded_files.
 
@@ -174,7 +195,6 @@ def patch(
         with open(patch_file, newline="") as f, open(
             filtered_patch, "w", newline=""
         ) as fdout:
-
             # Two line headers that mark beginning of patches
             header1: tuple | tuple[str, str] = ()
             header2: tuple | tuple[str, str] = ()
@@ -270,6 +290,6 @@ def patch(
         files_to_patch = process_regular_patch()
 
     if files_to_patch == 0:
-        raise DiffError(origin="patch", message="No file to patch")
+        raise EmptyDiffError(origin="patch", message="No file to patch")
 
     apply_patch(filtered_patch)
