@@ -1,22 +1,55 @@
 import logging
 import os
+import pytest
 
 from e3.anod.checkout import CheckoutManager
 from e3.anod.status import ReturnValue
 from e3.vcs.svn import SVNRepository
 from e3.vcs.git import GitRepository
+from e3.fs import mkdir
 from e3.os.fs import touch
+import uuid
+import time
+
+
+def test_rsync_mode():
+    """Check that rsync mode is faster than default mode."""
+    mkdir("work")
+    mkdir("work2")
+    GitRepository.create("git")
+    for _ in range(1000):
+        name = str(uuid.uuid1(clock_seq=int(1000 * time.time())))
+        touch(os.path.join("git", name + ".py"))
+        touch(os.path.join("git", name + ".pyc"))
+        touch(os.path.join("git", name + ".o"))
+        touch(os.path.join("git", name + ".ali"))
+
+    with open("git/.gitignore", "w") as fd:
+        fd.write("*.pyc\n")
+        fd.write("*.o\n")
+        fd.write("*.ali\n")
+
+    m = CheckoutManager(name="myrepo", working_dir="work")
+    m.update(vcs="external", url=os.path.abspath("git"))
+
+    os.environ["E3_ENABLE_FEATURE"] = "use-rsync"
+
+    m = CheckoutManager(name="myrepo", working_dir="work2")
+    m.update(vcs="external", url=os.path.abspath("git"))
 
 
 class TestCheckout:
     repo_data = os.path.join(os.path.dirname(__file__), "vcs_data")
     repo_data2 = os.path.join(os.path.dirname(__file__), "vcs_data2")
 
-    def test_svn_checkout(self):
+    @pytest.mark.parametrize("compute_changelog", [True, False])
+    @pytest.mark.parametrize("e3_feature", ["", "git_shallow_fetch"])
+    def test_svn_checkout(self, svn, compute_changelog, e3_feature):
         os.environ["GIT_AUTHOR_EMAIL"] = "e3-core@example.net"
         os.environ["GIT_AUTHOR_NAME"] = "e3 core"
         os.environ["GIT_COMMITTER_NAME"] = "e3-core@example.net"
         os.environ["GIT_COMMITTER_EMAIL"] = "e3 core"
+        os.environ["E3_ENABLE_FEATURE"] = e3_feature
 
         url = SVNRepository.create("svn", initial_content_path=self.repo_data)
         url2 = SVNRepository.create("svn2", initial_content_path=self.repo_data2)
@@ -26,7 +59,9 @@ class TestCheckout:
         r = SVNRepository(working_copy=os.path.abspath("svn_checkout"))
         r.update(url=url)
 
-        m = CheckoutManager(name="myrepo", working_dir=".")
+        m = CheckoutManager(
+            name="myrepo", working_dir=".", compute_changelog=compute_changelog
+        )
 
         logging.info("update of non existing url")
         result = m.update(vcs="svn", url=url + "wrong_url")
@@ -99,9 +134,6 @@ class TestCheckout:
         with open(os.path.join("myrepo", "file3.txt")) as fd:
             assert fd.read().strip() == "new file!"
 
-        result = m.update(vcs="future-vcs", url="dummy")
-        assert result == ReturnValue.failure
-
         result = m.update(vcs="git", url=url4 + "non-existing", revision="master")
         assert result == ReturnValue.failure
 
