@@ -12,7 +12,6 @@ import pytest
 
 def test_simple_spec():
     class Simple(Anod):
-
         test_qualifier_format = (("with_bar", False),)
 
         build_source_list = [
@@ -41,7 +40,6 @@ def test_spec_buildvars():
     """Build vars are used by the driver and not visible in deps."""
 
     class MySpec(Anod):
-
         build_deps = [Anod.BuildVar("key", "value")]
 
         @Anod.primitive()
@@ -72,7 +70,6 @@ def test_primitive():
     assert has_primitive(no_primitive, "build") is False
 
     class WithPrimitive(Anod):
-
         build_qualifier_format = (("error", False),)
 
         package = Anod.Package(prefix="mypackage", version=lambda: "42")
@@ -130,3 +127,32 @@ def test_api_version():
 
     with pytest.raises(AnodError):
         check_api_version("0.0")
+
+
+def test_spec_qualifier():
+    class GeneratorEnabled(Anod):
+        enable_name_generator = True
+
+        def declare_qualifiers_and_components(self, qm):
+            qm.declare_tag_qualifier(
+                "q1",
+                description="???",
+            )
+
+    class GeneratorDisabled(Anod):
+        enable_name_generator = False
+
+    spec_enable = GeneratorEnabled(qualifier="q1", kind="build")
+    spec_disable = GeneratorDisabled(qualifier="q1", kind="build")
+
+    assert spec_enable.args == {"q1": True}
+    assert spec_disable.args == {"q1": ""}
+
+
+def test_missing_property():
+    class NoProperty(Anod):
+        def source_pkg_build(self) -> list:
+            return []
+
+    noproperty = NoProperty(qualifier="", kind="source")
+    assert noproperty.source_pkg_build == []
