@@ -1,12 +1,18 @@
+from __future__ import annotations
+
 import os
 import sys
+import subprocess
 import textwrap
 import time
+import signal
 
 import e3.fs
 import e3.os.fs
 import e3.os.process
 
+from e3.env import Env
+
 import pytest
 
 from subprocess import STDOUT
@@ -17,6 +23,28 @@ except ImportError:
     psutil = None
 
 
+def test_run_stdout_stderr():
+    """Check Run with partial redirection.
+
+    Verify that Run is working when stdout is redirected to a file and
+    stderr not redirected to stdout.
+    """
+    prog_filename = os.path.join(os.getcwd(), "prog")
+    with open(prog_filename, "wb") as f:
+        f.write(b"import sys\n")
+        f.write(b'print("stdout", file=sys.stdout)\n')
+        f.write(b'print("stderr", file=sys.stderr)\n')
+    e3.os.fs.chmod("a+x", prog_filename)
+    p = e3.os.process.Run([sys.executable, prog_filename], error=subprocess.PIPE)
+    assert p.out.replace("\r", "") == "stdout\n"
+    assert p.err.replace("\r", "") == "stderr\n"
+    p = e3.os.process.Run(
+        [sys.executable, prog_filename], output="text.txt", error=subprocess.PIPE
+    )
+    assert os.path.isfile("text.txt")
+    assert p.err.replace("\r", "") == "stderr\n"
+
+
 def test_run_shebang(caplog):
     """Verify that the parse shebang option works."""
     prog_filename = os.path.join(os.getcwd(), "prog")
@@ -83,7 +111,7 @@ def test_rlimit():
     if sys.platform == "win32":
         # On Windows make sure that rlimit works when
         # setting the build environment to 64bit windows
-        e = e3.env.Env()
+        e = Env()
         e.store()
         e.set_build("x86_64-windows")
         run_test()
@@ -92,6 +120,120 @@ def test_rlimit():
         e.restore()
 
 
+@pytest.mark.skipif(sys.platform == "win32", reason="A linux/macOS test")
+def test_rlimit_ctrl_c():
+    """Test rlimit CTRL-C.
+
+    When a parent process launched two or more child processes using rlimit, the CTRL-C
+    command no longer worked.
+
+    This was because when an rlimit process was launched, it became the foreground
+    process.
+
+    However, when the foreground process was killed, it left the parent process without
+    a foreground, so CTRL-C was ignored.
+
+    Examples:
+       Example 1: Spawn 1 rlimit child process:
+            python (Parent process)
+            |
+            -> rlimit (Child process / foreground process)
+
+            A CTRL-C appear:
+                The child process in the foreground was killed, leaving the parent
+                process alone with no foreground process but no child. Due to our
+                usage, this posed no known problems. However, leaving the parent
+                process without a foreground can cause unexpected results.
+
+       Example 2: Spawn 2 rlimit child process:
+            python (Parent process)
+            |
+            -> rlimit (Child process) ==> This process was the foreground process as
+            |                             long as no other rlimit process was running.
+            |                             In this example, we have 2 rlimit processes,
+            |                             so this process is not in the foreground.
+            |
+            -> rlimit (Child process / foreground process)
+
+            A CTRL-C appear:
+                The foreground process has been killed, leaving no foreground process.
+                Signals were no longer propagated, so CTRL-C did nothing.
+    """
+    try:
+        from ptyprocess import PtyProcess
+    except ImportError:
+        raise ImportError("ptyprocess is needed to run this tests") from None
+
+    script_to_run = """
+from __future__ import annotations
+
+import sys
+from e3.os.process import Run
+
+p2 = Run(["sleep", "100"], timeout=30, bg=True)
+p1 = Run(["sleep", "10"], timeout=1)
+# CTRL-C is now blocking
+p2.wait()
+"""
+
+    with open("tmp-test_rlimic_ctrl_c.py", "w") as f:
+        f.write(script_to_run)
+
+    start = time.perf_counter()
+    p = PtyProcess.spawn([sys.executable, "tmp-test_rlimic_ctrl_c.py"])
+    time.sleep(5)
+    p.sendintr()
+    # !!! Warning:
+    #   if the script_to_run write something on stdout, this will wait forever.
+    p.wait()
+    end = time.perf_counter()
+    assert int(end - start) < 30, f"CTRL-C failed: take {int(end - start)} seconds"
+
+
+@pytest.mark.skipif(sys.platform != "linux", reason="A linux test")
+def test_rlimit_foreground_option():
+    """Test rlimit --foreground.
+
+    Test if we can read/write from an interactive terminal using rlimit --foreground.
+    """
+    try:
+        from ptyprocess import PtyProcess
+    except ImportError:
+        raise ImportError("ptyprocess is needed to run this tests") from None
+
+    # Test with --foreground
+    os.environ["PS1"] = "$ "
+    # Use TERM=dummy to avoid prompt coloring to interfere with the result
+    # string.
+    os.environ["TERM"] = "dummy"
+    p = PtyProcess.spawn(
+        [e3.os.process.get_rlimit(), "--foreground", "30", "bash", "--norc", "-i"],
+        env=os.environ,
+        echo=False,
+    )
+    p.write(b"echo 'test rlimit --foreground'\n", flush=True)
+    time.sleep(2)
+    assert p.read() == b"$ test rlimit --foreground\r\n$ "
+    # Ensure that the process is killed
+    p.kill(signal.SIGKILL)
+
+    # Test without foreground (Should fail)
+    p = PtyProcess.spawn(
+        [e3.os.process.get_rlimit(), "30", "bash", "--norc", "-i"],
+        env=os.environ,
+        echo=False,
+    )
+    p.write(b"echo 'test rlimit (no --foreground)'\n", flush=True)
+    time.sleep(2)
+    with pytest.raises(EOFError):
+        # The echo command should not be executed by bash. So p.read() will raise an
+        # EOFError. And if not, we will raise an Exception because this is not
+        # what we want.
+        p.read()
+        # Ensure that the process is killed
+    p.kill(signal.SIGKILL)
+
+
 def test_not_found():
     with pytest.raises(OSError) as err:
         e3.os.process.Run(["e3-bin-not-found"])
@@ -250,7 +392,7 @@ def test_is_running():
     assert e3.os.process.is_running(p.pid)
     p.kill(recursive=False)
 
-    # On windows we don't want to wait as otherwise pid will be reused
+    # On windows, we don't want to wait as otherwise pid will be reused
     # Note also that the semantic is slightly different between Unix
     # and Windows. is_running will report false on Windows once the
     # process is in a waitable state.
@@ -267,7 +409,9 @@ def test_is_running_non_existant():
     pid_list = psutil.pids()
     pid_list.sort()
 
-    # Try to found a non existing process
+    running: bool = True
+
+    # Try to found a non-existing process
     for a in range(1, 1000):
         running = e3.os.process.is_running(pid_list[-1] + a)
         if not running:
@@ -365,14 +509,12 @@ def test_kill_process_tree():
 
 def test_run_with_env():
     os.environ["EXT_VAR"] = "bar"
-    cmd = (
-        [
-            sys.executable,
-            "-c",
-            'import os; print(os.environ.get("TEST_RUN_VAR")'
-            ' + os.environ.get("EXT_VAR", "world"))',
-        ],
-    )
+    cmd = [
+        sys.executable,
+        "-c",
+        'import os; print(os.environ.get("TEST_RUN_VAR")'
+        ' + os.environ.get("EXT_VAR", "world"))',
+    ]
     p1 = e3.os.process.Run(cmd, env={"TEST_RUN_VAR": "foo"}, ignore_environ=False)
     assert p1.out.strip() == "foobar"
 
@@ -397,7 +539,7 @@ def test_no_rlimit(caplog):
 def test_shell_override():
     """Unix shell shebang handling.
 
-    On windows we ensure that /bin/bash /bin/sh shebangs are replaced by
+    On windows, we ensure that /bin/bash /bin/sh shebangs are replaced by
     SHELL env var.
     """
     work_dir = os.getcwd()
